@@ -1192,8 +1192,8 @@ class DebuggerUI(FrameVarInfoKeeper):
                     ext = ".py"
                     filename = base+".py"
 
-                self.set_source_code_provider(self.debugger,
-                        FileSourceCodeProvider(filename))
+                self.set_source_code_provider(
+                        FileSourceCodeProvider(self.debugger, filename))
                 self.source_list.set_focus(0)
 
             class FilterEdit(urwid.Edit):
@@ -1334,6 +1334,8 @@ class DebuggerUI(FrameVarInfoKeeper):
 
             completed_chopped_text = \
                     Completer(cmdline_get_namespace()).complete(chopped_text, 0)
+            if completed_chopped_text is None:
+                completed_chopped_text = chopped_text
 
             self.cmdline_edit.edit_text = \
                     completed_chopped_text+remainder_text
@@ -1355,6 +1357,7 @@ class DebuggerUI(FrameVarInfoKeeper):
 
             self.cmdline_history_position = -1
 
+            prev_sys_stdin = sys.stdin
             prev_sys_stdout = sys.stdout
             prev_sys_stderr = sys.stderr
 
@@ -1363,6 +1366,7 @@ class DebuggerUI(FrameVarInfoKeeper):
             else:
                 from cStringIO import StringIO
 
+            sys.stdin = None
             sys.stderr = sys.stdout = StringIO()
             try:
                 eval(compile(cmd, "<pudb command line>", 'single'),
@@ -1386,6 +1390,7 @@ class DebuggerUI(FrameVarInfoKeeper):
                 if sys.stdout.getvalue():
                     add_cmdline_content(sys.stdout.getvalue(), "command line output")
 
+                sys.stdin = prev_sys_stdin
                 sys.stdout = prev_sys_stdout
                 sys.stderr = prev_sys_stderr
 
@@ -1852,7 +1857,7 @@ class DebuggerUI(FrameVarInfoKeeper):
                 self.message("Package 'pygments' not found. "
                         "Syntax highlighting disabled.")
 
-        WELCOME_LEVEL = "e017"
+        WELCOME_LEVEL = "e018"
         if CONFIG["seen_welcome"] < WELCOME_LEVEL:
             CONFIG["seen_welcome"] = WELCOME_LEVEL
             from pudb import VERSION
@@ -1869,6 +1874,11 @@ class DebuggerUI(FrameVarInfoKeeper):
                     "(invoked by hitting '?' after this message) should get you "
                     "on your way.\n"
 
+                    "\nChanges in version 2013.5.1:\n\n"
+                    "- Fix loading of saved breakpoint conditions (Antoine Dechaume)\n"
+                    "- Fixes for built-in command line\n"
+                    "- Theme updates\n"
+
                     "\nChanges in version 2013.5:\n\n"
                     "- Add command line window\n"
                     "- Uses curses display driver when appropriate\n"
